/**
 * 
 */
package com.example.server.service;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.example.server.dao.IRemoteDAO;
import com.example.server.exception.AccountException;
import com.example.server.model.RemoteAccount;

/**
 * @author PradeepBadiger
 * 
 */
@Service
public class RemoteService {

	private static final Logger LOGGER = Logger.getLogger(RemoteService.class);

	@Autowired
	private IRemoteDAO remoteDAO;

	/**
	 * Saves and returns remote account record.
	 * 
	 * @param remoteAccount
	 * @return
	 * @throws AccountException
	 */
	@Transactional(propagation = Propagation.MANDATORY)
	// This should use the transaction initiated by ws client.
	public RemoteAccount saveRecord(RemoteAccount remoteAccount, String testCaseId)
			throws AccountException {
		LOGGER.info("Saving Remote Account object......\n");
		RemoteAccount account = remoteDAO.saveRecord(remoteAccount);

		if("REMOTE_ROLLBACK".equals(testCaseId)) {
			throw new AccountException("Remote rollback data.");
		}
		
		LOGGER.info("Saved Remote Account object successfully.");
		return account;
	}
}
